.. image:: https://raw.githubusercontent.com/openforis/sepal-doc/master/docs/source/_images/sepal_header.png

Sepal_ui
--------

.. image:: https://img.shields.io/badge/License-MIT-yellow.svg
    :target: https://opensource.org/licenses/MIT
    :alt: License: MIT

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black badge

.. image:: https://img.shields.io/badge/code_style-prettier-ff69b4.svg
   :target: https://github.com/prettier/prettier
   :alt: prettier badge

.. image:: https://img.shields.io/badge/Conventional%20Commits-1.0.0-yellow.svg
   :target: https://conventionalcommits.org
   :alt: conventional commit

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.6467834.svg
   :target: https://doi.org/10.5281/zenodo.6467834
   :alt: Citation

.. image:: https://img.shields.io/readthedocs/sepal_ui?logo=readthedocs&logoColor=white
    :target: https://sepal-ui.readthedocs.io/en/latest/
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/sepal-ui?color=orange&logo=python&logoColor=white
    :target: https://pypi.org/project/sepal-ui/
    :alt: PyPI version

.. image:: https://img.shields.io/conda/vn/conda-forge/sepal-ui?color=orange&logo=anaconda&logoColor=white
    :target: https://anaconda.org/conda-forge/sepal-ui
    :alt: Conda Version

.. image:: https://img.shields.io/pypi/pyversions/sepal-ui?color=orange&logo=python&logoColor=white
   :target: https://pypi.org/project/sepal-ui/
   :alt: supported Python version

.. image:: https://img.shields.io/github/actions/workflow/status/12rambau/sepal_ui/unit.yml?logo=github&logoColor=white
    :target: https://github.com/12rambau/sepal_ui/actions/workflows/unit.yml
    :alt: build

.. image:: https://img.shields.io/codeclimate/maintainability/12rambau/sepal_ui?logo=codeclimate&logoColor=white
    :target: https://codeclimate.com/github/12rambau/sepal_ui/maintainability
    :alt: Maintainability

.. image:: https://img.shields.io/codecov/c/github/12rambau/sepal_ui?logo=codecov&logoColor=white
    :target: https://codecov.io/gh/12rambau/sepal_ui
    :alt: Test Coverage

--------------------------------------------------------------------------------

Currently translated in the following languages:

.. list-table::

   * - English
     - Français
     - Español
     - 中国人
   * - .. image:: https://img.shields.io/static/v1?label=en&message=100%&logo=crowdin&logoColor=white&color=blue
     - .. image:: https://img.shields.io/badge/dynamic/json?label=fr&logo=crowdin&logoColor=white&query=%24.progress.2.data.translationProgress&url=https%3A%2F%2Fbadges.awesome-crowdin.com%2Fstats-15167678-506362.json
     - .. image:: https://img.shields.io/badge/dynamic/json?logoColor=white&label=es-ES&logo=crowdin&query=%24.progress.1.data.translationProgress&url=https%3A%2F%2Fbadges.awesome-crowdin.com%2Fstats-15167678-506362.json
     - .. image:: https://img.shields.io/badge/dynamic/json?label=zh-CN&logo=crowdin&logoColor=white&query=%24.progress.5.data.translationProgress&url=https%3A%2F%2Fbadges.awesome-crowdin.com%2Fstats-15167678-506362.json

You can contribute to the translation effort on our `crowdin project <https://crowdin.com/project/sepal-ui>`__.

--------------------------------------------------------------------------------

:code:`sepal_ui` is a lib designed to create elegant python based dashboard in the `SEPAL environment <https://sepal.io/>`__. It is designed on top of the amazing `ipyvuetify <https://ipyvuetify.readthedocs.io/en/latest/introduction.html>`_ library and will help developer to easily create interface for their workflows.
By using this libraries, you'll ensure a robust and unified interface for your scripts and a easy and complete integration into the SEPAL dashboard of application.

The full documentation is available `here <https://sepal-ui.readthedocs.io/en/latest/>`__ and demo apps can be launched on Heroku following these links:

-   `Map style application <https://sepal-map-app.herokuapp.com>`__
-   `Panel style application <https://sepal-panel-app.herokuapp.com>`__

We are happy to receive feedback and we welcome any kind of contribution.

+-----------+-------------+
| |map-app| | |panel-app| |
+-----------+-------------+

.. |map-app| image:: https://raw.githubusercontent.com/12rambau/sepal_ui/main/docs/source/_image/demo-map-app.png
    :width: 100%

.. |panel-app| image:: https://raw.githubusercontent.com/12rambau/sepal_ui/main/docs/source/_image/demo-panel-app.png
    :width: 100%

Contribute
----------

If you want to contribute you can fork the project in you own repository and then use it.
If you consider working with us, please follow the `contributing guidelines <CONTRIBUTING.rst>`__.

Meet our `contributor <AUTHORS.rst>`__.

